# SPDX-License-Identifier: MIT


# Import local modules.
from .main import *

# Set version information.
__version_info__ = ('2024', '2', '17')  # YYYY / MM / DD
__version__ = '.'.join(__version_info__)
